# CircuiTree
Genetic circuit design using Monte Carlo tree search

## Installation

### From a package repository
To install using `pip`:

```pip install circuitree```

### From the GitHub repository

To install and use `circuitree` from the GitHub source code, first clone the repo into a directory.

```git clone https://github.com/pranav-bhamidipati/circuitree.git[ dir_name]```

Then, you can build the environment using the command-line tool `poetry`. Instructions for installation can be [found here](https://python-poetry.org/). 

From the main project directory, run `poetry install` to install a virtual environment with `circuitree` installed. The easiest way to use this environment is to run it interactively with `poetry shell`. Alternatively, you can run a command in the virtual environment with `poetry run <command>`. For instance, to launch a Jupyter notebook with `circuitree` pre-loaded, run `poetry run jupyter notebook`. 

## Usage

See the [quick-start demo](examples/quick_start.ipynb).
